Function windows_version::is_server
source · pub fn is_server() -> boolExpand description
Determines if the currently running operating system is a Windows Server release.
pub fn is_server() -> boolDetermines if the currently running operating system is a Windows Server release.